django_dicom.filters package — django_dicom 0.1.0 documentation

# django_dicom.filters package

## Module contents

Provides filter classes for the REST API endpoints (more information).

## Submodules

## django_dicom.filters.image_filter module

class `django_dicom.filters.image_filter.` `ImageFilter`(data=None, queryset=None, *, request=None, prefix=None)

  Bases: `django_filters.rest_framework.filterset.FilterSet`

  Provides useful filtering options for the `Image` class.

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'uid', 'series_uid', 'series_description', 'created_after_date', 'created_before_date', 'created_after_time', 'created_before_time', 'number')
    `model`

      alias of `django_dicom.models.image.Image`

  `base_filters` = {'created_after_date': <django_filters.filters.DateFilter object>, 'created_after_time': <django_filters.filters.DateFilter object>, 'created_before_date': <django_filters.filters.DateFilter object>, 'created_before_time': <django_filters.filters.DateFilter object>, 'id': <django_filters.filters.NumberFilter object>, 'number': <django_filters.filters.NumberFilter object>, 'series_description': <django_filters.filters.CharFilter object>, 'series_uid': <django_filters.filters.CharFilter object>, 'uid': <django_filters.filters.CharFilter object>}
  `declared_filters` = {'created_after_date': <django_filters.filters.DateFilter object>, 'created_after_time': <django_filters.filters.DateFilter object>, 'created_before_date': <django_filters.filters.DateFilter object>, 'created_before_time': <django_filters.filters.DateFilter object>, 'series_description': <django_filters.filters.CharFilter object>, 'series_uid': <django_filters.filters.CharFilter object>}